<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you (the theme developer).
 * will need to copy the new files to your theme to maintain compatibility. We try to do this.
 * as little as possible, but it does happen. When this occurs the version of the template file will.
 * be bumped and the readme will list any important changes.
 *
 * @see     http://docs.woothemes.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.3.8
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

wc_print_notices();

do_action( 'woocommerce_before_cart' ); ?>
<ul id="my-id" class="uk-subnav tm-portfolio-navigation">
  <li class="is-active"><a href="<?php echo get_site_url(); ?>/cart">Cart</a></li>
  <li><a href="<?php echo get_site_url(); ?>/checkout"><?php esc_html_e( 'Checkout', 'boss' ); ?></a></li>
</ul>

<div class="tm-shop-cart">
<form action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">

<?php do_action( 'woocommerce_before_cart_table' ); ?>

<table class="shop_table shop_table_responsive cart" cellspacing="0">
	<thead>
		<tr>
			<th class="product-remove"><?php esc_html_e( 'Remove', 'boss' ); ?></th>
			<th class="product-thumbnail"><?php esc_html_e( 'Image', 'boss' ); ?></th>
			<th class="product-name"><?php esc_html_e( 'Product', 'boss' ); ?></th>
			<th class="product-price"><?php esc_html_e( 'Price', 'boss' ); ?></th>
			<th class="product-quantity"><?php esc_html_e( 'Quantity', 'boss' ); ?></th>
			<th class="product-subtotal"><?php esc_html_e( 'Total', 'boss' ); ?></th>
		</tr>
	</thead>
	<tbody>
		<?php do_action( 'woocommerce_before_cart_contents' ); ?>

		<?php
		foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
			$_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
			$product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

			if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
				?>
				<tr class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

					<td class="product-remove">
						<?php
							echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
								'<a href="%s" class="remove" title="%s" data-product_id="%s" data-product_sku="%s">&times;</a>',
								esc_url( WC()->cart->get_remove_url( $cart_item_key ) ),
								__( 'Remove this item', 'boss' ),
								esc_attr( $product_id ),
								esc_attr( $_product->get_sku() )
							), $cart_item_key );
						?>
					</td>

					<td class="product-thumbnail">
						<?php
							$thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

							if ( ! $_product->is_visible() ) {
								echo $thumbnail;
							} else {
								printf( '<a href="%s">%s</a>', esc_url( $_product->get_permalink( $cart_item ) ), $thumbnail );
							}
						?>
					</td>

					<td class="product-name" data-title="<?php esc_html_e( 'Product', 'boss' ); ?>">
						<?php
							if ( ! $_product->is_visible() ) {
								echo apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key ) . '&nbsp;';
							} else {
								echo apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $_product->get_permalink( $cart_item ) ), $_product->get_title() ), $cart_item, $cart_item_key );
							}

							// Meta data
							echo WC()->cart->get_item_data( $cart_item );

							// Backorder notification
							if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
								echo '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'boss' ) . '</p>';
							}
						?>
					</td>

					<td class="product-price" data-title="<?php esc_html_e( 'Price', 'boss' ); ?>">
						<?php
							echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
						?>
					</td>

					<td class="product-quantity" data-title="<?php esc_html_e( 'Quantity', 'boss' ); ?>">
						<?php
							if ( $_product->is_sold_individually() ) {
								$product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
							} else {
								$product_quantity = woocommerce_quantity_input( array(
									'input_name'  => "cart[{$cart_item_key}][qty]",
									'input_value' => $cart_item['quantity'],
									'max_value'   => $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(),
									'min_value'   => '0'
								), $_product, false );
							}
							echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item );
						?>
					</td>

					<td class="product-subtotal" data-title="<?php esc_html_e( 'Total', 'boss' ); ?>">
						<?php
							echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );
						?>
					</td>
				</tr>
				<?php
			}
		}

		do_action( 'woocommerce_cart_contents' );
		?>
		<?php do_action( 'woocommerce_after_cart_contents' ); ?>
	</tbody>
</table>

<?php do_action( 'woocommerce_after_cart_table' ); ?>

</form>

	<div class="uk-grid uk-grid-margin">
		<div class="uk-width-1-1 uk-width-small-1-2">
			<div class="wc-proceed-to-checkout">
				<div class="uk-grid" data-uk-observe>
					<div class="uk-width-large-1-2 uk-width-medium-1-1">
						<a href="<?php echo get_site_url(); ?>/checkout/" class="checkout-buttons button alt wc-forward"><?php esc_html_e( 'CHECKOUT', 'boss' ); ?></a>
					</div>
					<div class="uk-width-large-1-2 uk-width-medium-1-1">
						<a href="<?php echo get_site_url(); ?>/shop/" class="checkout-buttons button alt wc-forward"><?php esc_html_e( 'back to shopping', 'boss' ); ?></a>
					</div>
				</div>
			</div>
		</div>
		<div class="uk-width-1-1 uk-width-small-1-2">
			<div class="tt-cart-collaterals">
				<div class="<?php if ( WC()->customer->has_calculated_shipping() ) echo 'calculated_shipping'; ?>">
					<?php do_action( 'woocommerce_before_cart_totals' ); ?>
					<div class="uk-grid">
						<div class="uk-width-1-1" class="cart-subtotal">
							<h3><?php esc_html_e( 'Total cart', 'boss' ); ?></h3>
							<h3 class="tt-title-collaterals"><?php wc_cart_totals_subtotal_html(); ?></h3>
							<br />
							<?php if ( WC()->cart->needs_shipping() && WC()->cart->show_shipping() ) : ?>
								<?php do_action( 'woocommerce_cart_totals_before_shipping' ); ?>
								<?php wc_cart_totals_shipping_html(); ?>
								<?php do_action( 'woocommerce_cart_totals_after_shipping' ); ?>
							<?php endif; ?>
							<br />
							<?php do_action( 'woocommerce_cart_totals_before_order_total' ); ?>
							<div class="tt-order-total">
								<h3><?php esc_html_e( 'Order total', 'boss' ); ?></h3>
								<h3 class="tt-title-collaterals"><?php wc_cart_totals_order_total_html(); ?></h3>
							</div>
						</div>
						<?php do_action( 'woocommerce_cart_totals_after_order_total' ); ?>
						<?php do_action( 'woocommerce_after_cart_totals' ); ?>
					</div>
				</div>
			</div>
		</div>
	</div>

	<div class="tm-before-cart-content" >
		<div class="uk-grid">
			<div class="uk-width-large-1-2 uk-width-medium-1-1">
				<?php if ( WC()->cart->coupons_enabled() ) { ?>
					<div class="coupon">
						<h2><?php esc_html_e( 'Discount', 'boss' ); ?></h2>
						<input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupone code', 'boss' ); ?>" /> <input type="submit" class="button" name="apply_coupon" value="<?php esc_attr_e( 'Apply Coupon', 'boss' ); ?>" />
						<?php do_action( 'woocommerce_cart_coupon' ); ?>
					</div>
				<?php } ?>
				<?php do_action( 'woocommerce_cart_actions' ); ?>
				<?php wp_nonce_field( 'woocommerce-cart' ); ?>
			</div>
			<div class="uk-width-large-1-2 uk-width-medium-1-1">
				<?php do_action( 'woocommerce_before_shipping_calculator' ); ?>
				<form class="woocommerce-shipping-calculator" action="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" method="post">
					<h2 href="#" class="shipping-calculator-button">Estimate shipping and tax</h2>
					<section class="shipping-calculator-form" style="display:none;">
						<div>
							<div class="uk-width-1-1">
								<div id="jelectTool1" role="combobox" class="jelect js-jelect">
									<?php $counter = 0; ?>
									<input id="jelectToolInput" value="0" data-text="gulp" type="text" class="jelect-input js-jelect-input">
									<div tabindex="1" role="button" class="jelect-current js-jelect-current">
										<?php esc_html_e( 'Select a country&hellip;', 'boss' ); ?>
									</div>
									<div role="list-box" class="jelect-options js-jelect-options">
										<div class="jelect-scroller js-jelect-scroller">
											<?php
											foreach( WC()->countries->get_shipping_countries() as $key => $value )
												echo '<div data-val="'.$counter++.'" tabindex="'.$counter++.'" role="option" class="jelect-option js-jelect-option"><div class="jelect-option__value js-jelect-option-value">' . esc_html( $value ) .'</div></div>';
											?>
										</div>
										<div class="jelect-track">
											<div class="jelect-scrollbar js-jelect-scrollbar"></div>
										</div>
									</div>
								</div>
							</div>
							<div class="uk-width-1-1">
								<div>
									<div class="uk-width-1-2">
										<?php

											$current_cc = WC()->customer->get_shipping_country();
											$current_r  = WC()->customer->get_shipping_state();
											$states     = WC()->countries->get_states( $current_cc );


											if ( is_array( $states ) && empty( $states ) ) {
											?><input type="hidden" name="calc_shipping_state" id="calc_shipping_state" placeholder="<?php esc_attr_e( 'State / county', 'boss' ); ?>" /><?php
											} elseif ( is_array( $states ) ) { ?>
											<div id="jelectTool1" role="combobox" class="jelect js-jelect">
												<?php $counter = 0; ?>
												<input id="jelectToolInput" value="0" data-text="gulp" type="text" class="jelect-input js-jelect-input">
												<div tabindex="1" role="button" class="jelect-current js-jelect-current">
													<?php esc_attr_e( 'State / county', 'boss' ); ?>
												</div>
												<div role="list-box" class="jelect-options js-jelect-options">
													<div class="jelect-scroller js-jelect-scroller">
														<?php
														foreach ( $states as $ckey => $cvalue )
														echo '<div data-val="'.$counter++.'" tabindex="'.$counter++.'" role="option" class="jelect-option js-jelect-option"><div class="jelect-option__value js-jelect-option-value">' . esc_html( $cvalue ) .'</div></div>';
														?>
													</div>
													<div class="jelect-track">
														<div class="jelect-scrollbar js-jelect-scrollbar"></div>
													</div>
												</div>
											</div>
										<?php
										} else {

										?>
										<input type="text" class="tm-post-code input-text" value="<?php echo esc_attr( $current_r ); ?>" placeholder="<?php esc_attr_e( 'State / county', 'boss' ); ?>" name="calc_shipping_state" id="calc_shipping_state" /><?php
										}
										?>
									</div>
									<?php if ( apply_filters( 'woocommerce_shipping_calculator_enable_city', false ) ) : ?>
										<div class="uk-width-1-2">
											<input type="text" class="tm-post-code input-text" value="<?php echo esc_attr( WC()->customer->get_shipping_city() ); ?>" placeholder="<?php esc_attr_e( 'City', 'boss' ); ?>" name="calc_shipping_city" id="calc_shipping_city" />
										</div>
									<?php endif; ?>
									<?php if ( apply_filters( 'woocommerce_shipping_calculator_enable_postcode', true ) ) : ?>
									<div class="uk-width-1-2">
										<input type="text" class="tm-post-code" value="<?php echo esc_attr( WC()->customer->get_shipping_postcode() ); ?>" placeholder="<?php esc_attr_e( 'Postcode / Zip', 'boss' ); ?>" name="calc_shipping_postcode" id="calc_shipping_postcode" />
									</div>
									<?php endif; ?>
								</div>
							</div>
						</div>
					</section>
				</form>
				<?php do_action( 'woocommerce_after_shipping_calculator' ); ?>
			</div>
		</div>
	</div>

</div>
<?php do_action( 'woocommerce_after_cart' ); ?>
